"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// Copyright (c) 2020 GitHub. This code is licensed under MIT license (see LICENSE(https://github.com/github/dynamic-template-engine/blob/master/LICENSE) for details)
const HandleBarsTemplateEngine_1 = require("../Engine/HandleBarsTemplateEngine");
const TransformContract_1 = require("../../Transformer/Core/TransformContract");
const LiquidTemplateEngine_1 = require("../Engine/LiquidTemplateEngine");
const TemplateError_1 = require("../../Error/TemplateError");
/**
 * A singleton class
 * TemplateEngineFactory provides a method to get right engine based on template type.
 */
class TemplateEngineFactory {
    /**
     * Private constructor sets up the templateEngineMap
     */
    constructor() {
        this.templateEngineMap = new Map();
        this.templateEngineMap.set(TransformContract_1.TemplateType.HandleBars, new HandleBarsTemplateEngine_1.default());
        this.templateEngineMap.set(TransformContract_1.TemplateType.Liquid, new LiquidTemplateEngine_1.default());
    }
    /**
     * Get instance of the singleton class.
     *
     * @returns {TemplateEngineFactory} Instance of TemplateEngineFactory
     */
    static getInstance() {
        return this.instance;
    }
    /**
     * Gets template engine of the provided type.
     *
     * @param {TemplateType} templateType - Type of the template engine, ex. Handlebars, Liquid
     * @returns {ITemplateEngine} template engine instance registered with the factory
     */
    getTemplateEngine(templateType) {
        const templateEngine = this.templateEngineMap.get(templateType);
        if (!templateEngine) {
            throw new TemplateError_1.TemplateEngineNotFound(`No template engine present for the TemplateType: ${templateType}`);
        }
        return templateEngine;
    }
}
exports.default = TemplateEngineFactory;
TemplateEngineFactory.instance = new TemplateEngineFactory();
//# sourceMappingURL=TemplateEngineFactory.js.map