"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// Copyright (c) 2020 GitHub. This code is licensed under MIT license (see LICENSE(https://github.com/github/dynamic-template-engine/blob/master/LICENSE) for details)
/* eslint-disable class-methods-use-this */
const TemplateEngineFactory_1 = require("../../Template/Core/TemplateEngineFactory");
const Utility_1 = require("../../Utility/Utility");
class Transformer {
    /**
     * calls the right templating engine and uses the same to render
     * the template inserting the data from the data object.
     *
     * @param {TemplateType} templateType - template engine to use ex. HandleBars, Liquid
     * @param {string} templateKey - template key with which the template is stored
     * @param {JSON} dataObject - data to be applied to the template
     */
    applyTemplate(templateType, templateKey, dataObject) {
        const templateEngine = TemplateEngineFactory_1.default.getInstance().getTemplateEngine(templateType);
        return templateEngine.applyTemplate(templateKey, dataObject);
    }
    /**
     * Fetch template file and register with appropriate template engine.
     *
     * @param {boolean} isHttpCall - boolean
     * @param {string} path - url/local path for the template file
     * @param {string} key - template key to use, to register template
     * @param {TemplateType} templateType - type of templating engine ex. Handlebars, Liquid
     */
    async readAndRegisterTemplate(isHttpCall, path, key, templateType) {
        const templateFile = await Utility_1.default.fetchFile(isHttpCall, path);
        const templateEngine = TemplateEngineFactory_1.default.getInstance().getTemplateEngine(templateType);
        templateEngine.registerTemplate(key, templateFile);
    }
}
exports.default = Transformer;
//# sourceMappingURL=Transformer.js.map